.. include:: ../global.rst

.. _api-classes:

API Return Classes
------------------

Abstract Base Class
~~~~~~~~~~~~~~~~~~~
.. autoclass:: jedi.api.classes.BaseName
    :members:
    :show-inheritance:

Name
~~~~
.. autoclass:: jedi.api.classes.Name
    :members:
    :show-inheritance:

Completion
~~~~~~~~~~
.. autoclass:: jedi.api.classes.Completion
    :members:
    :show-inheritance:

BaseSignature
~~~~~~~~~~~~~
.. autoclass:: jedi.api.classes.BaseSignature
    :members:
    :show-inheritance:

Signature
~~~~~~~~~
.. autoclass:: jedi.api.classes.Signature
    :members:
    :show-inheritance:

ParamName
~~~~~~~~~
.. autoclass:: jedi.api.classes.ParamName
    :members:
    :show-inheritance:

Refactoring
~~~~~~~~~~~

.. autoclass:: jedi.api.refactoring.Refactoring
    :members:
    :show-inheritance:

.. autoclass:: jedi.api.errors.SyntaxError
    :members:
    :show-inheritance:
